@@ -278,7 +278,7 @@ class ColorPicker:
         #self.showFgPicker()
         self.handler.show()
 
-    def showFgPicker(self):
+    def showFgPicker(self, message=None):
         """ Returns the color picked by the user
         """
         # Draw foreground colors 1-5 in a panel.
@@ -286,7 +286,7 @@ class ColorPicker:
         # to select color (arrows and return). Then return the
         # selected color.
         self.hidden = False
-        color = self.handler.showFgPicker()
+        color = self.handler.showFgPicker(message=message)
         if not self.caller.appState.sideBarShowing:
             self.hide()
         return color
@@ -429,7 +429,16 @@ class StatusBar():
         settingsMenu.add_item("VGA Colors", caller.enableTrueCGAColors, "v")
         settingsMenu.add_item("ZX Spectrum Colors", caller.enableTrueSpeccyColors, "z")
         settingsMenu.add_item("C64 Colors", caller.enableTrueC64Colors, "c")
-        settingsMenu.add_item("Deafult Colors", caller.resetColorsToDefault, "d")
+        #settingsMenu.add_item("Deafult Colors", caller.resetColorsToDefault, "d")
+        settingsMenu.add_item("Toggle Mouse", caller.toggleMouse, "m")
+        settingsMenu.add_item("Toggle Color Scroll", caller.toggleColorScrolling, "s")
+        settingsMenu.add_item("Toggle Wide Wrapping", caller.toggleWideWrapping, "w")
+        if self.appState.mental:    # Experimental stuff
+            settingsMenu.add_item("Toggle iCE Colors (MENTAL)", caller.toggleIceColors, "i")
+            settingsMenu.add_item("Toggle Injecting (MENTAL)", caller.toggleInjecting, "j")
+        if self.appState.debug:
+            settingsMenu.add_item("Toggle Debug", caller.toggleDebug, "d")
+            settingsMenu.add_item("Python Console", caller.jumpToPythonConsole, "p")
         settingsMenu.is_submenu = True
         #settingsMenu.add_item("Show/Hide Sidebar", caller.toggleSideBar, "s")
         settingsMenu.set_x(self.x - 1)
@@ -443,6 +452,7 @@ class StatusBar():
         transformMenu.add_item("Bounce", caller.transform_bounce, "b")
         transformMenu.add_item("Repeat", caller.transform_repeat, "r")
         transformMenu.add_item("Reverse", caller.transform_reverse, "v")
+        transformMenu.add_item("Apply NeoFetch Keys", caller.apply_neofetch_keys, "n")
         #transformMenu.add_item("Show/Hide Sidebar", caller.toggleSideBar, "s")
         transformMenu.set_x(self.x - 1)
         transformMenu.set_y(transformMenuColumn)
@@ -468,6 +478,7 @@ class StatusBar():
         mainMenu.add_item("Color Picker", caller.selectColorPicker, "l", shortcut="tab")
         mainMenu.add_item("Viewer Mode", caller.enterViewMode, "v", shortcut="esc-V")
         mainMenu.add_item("Find /", caller.searchForStringPrompt, "/", shortcut="esc-F")
+        mainMenu.add_item("Replace Color", caller.replaceColorUnderCursor, "e", shortcut="esc-L")
         mainMenu.add_item("Settings", caller.openSettingsMenu, "t", has_submenu=True)
         mainMenu.add_item("Help", caller.showHelp, "h", shortcut="esc-h")
         mainMenu.add_item("Quit", caller.safeQuit, "q", shortcut="esc-q")
